library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;


entity Main is
	port(vorodi1 : in std_logic_vector(6 downto 0);
			vorodi2 : in std_logic_vector(6 downto 0);
			clk_vorodi : in std_logic;
			apply_vorodi : in std_logic;
			blink_vorodi : in std_logic;
			output_khoroji : out std_logic_vector(7 downto 0);
			com_khoroji : out std_logic_vector(3 downto 0);
			led1_khoroji: out std_logic_vector(2 downto 0);
			led2_khoroji: out std_logic_vector(2 downto 0));
end Main;

architecture Behavioral of Main is

component controller is
	port(red_in : in std_logic_vector(6 downto 0);
			yellow_in : in std_logic_vector(6 downto 0);
			green_in : in std_logic_vector(6 downto 0);
			clk_con : in std_logic;
			led1_con: out std_logic_vector(2 downto 0);
			led2_con: out std_logic_vector(2 downto 0);
			seg1_con: out std_logic_vector(6 downto 0);
			seg2_con: out std_logic_vector(6 downto 0);
			mode_con: out std_logic_vector(1 downto 0);
			d_ready_con : in std_logic);
end component;

component freq_divider is
	generic (div: integer range 0 to 100000000:=0);
	Port ( clk_in_div : in  STD_LOGIC;
         clk_out_div : out  STD_LOGIC);
end component;

component segment is
	port(in1 : in std_logic_vector(6 downto 0);
			in2 : in std_logic_vector(6 downto 0);
			mode : in std_logic_vector(1 downto 0);
			clk : in std_logic;
			output : out std_logic_vector(7 downto 0);
			com : out std_logic_vector(3 downto 0));
end component;

component vorodi is
	port(in1 : in std_logic_vector(6 downto 0);
			in2 : in std_logic_vector(6 downto 0);
			apply : in std_logic;
			red : out std_logic_vector(6 downto 0);
			yellow : out std_logic_vector(6 downto 0);
			green : out std_logic_vector(6 downto 0);
			d_ready : out std_logic);
end component;

component MUX is
	port( inA : in std_logic_vector(21 downto 0);
			inB : in std_logic_vector(21 downto 0);
			blink: in std_logic:='0';
			outMUX : out std_logic_vector(21 downto 0));
end component;

component cheshmak_zan is
	port(clkin : in std_logic;
			led1: out std_logic_vector(2 downto 0);
			led2: out std_logic_vector(2 downto 0);
			seg1: out std_logic_vector(6 downto 0);
			seg2: out std_logic_vector(6 downto 0);
			mode1: out std_logic_vector(1 downto 0));
end component;


signal q1,q2,q3 : std_logic; --q1=0.5Hz , q2=1Hz , q3=1kHz
signal q4,q5,q6 : std_logic_vector(6 downto 0); -- vrodi be controller
signal ready :std_logic;
signal q7 , q8:std_logic_vector(21 downto 0); --khoroji blinker va controller
signal q9:std_logic_vector(21 downto 0);-- khoroji MUX

begin


U1: freq_divider generic  map(50000000) port map (clk_vorodi,q1);
U2: freq_divider generic  map(25000000) port map (clk_vorodi,q2);
U3: freq_divider generic  map(25000) port map (clk_vorodi,q3);
U4: vorodi port map (vorodi1, vorodi2, apply_vorodi, q4, q5, q6, ready);
U5: controller port map(q4, q5, q6, q2 , q7(2 downto 0),q7(5 downto 3),q7(12 downto 6),q7(19 downto 13),q7(21 downto 20), ready);
U6: cheshmak_zan port map(q1, q8(2 downto 0),q8(5 downto 3),q8(12 downto 6),q8(19 downto 13),q8(21 downto 20));
U7: MUX port map(q8, q7, blink_vorodi, q9);
U8: segment port map(q9(12 downto 6),q9(19 downto 13),q9(21 downto 20),q3, output_khoroji,com_khoroji);

led1_khoroji<= q9(2 downto 0);
led2_khoroji<= q9(5 downto 3);

end Behavioral;

